@@ -11,7 +11,8 @@
   s3_register("vctrs::vec_cast", "character.glue")
   s3_register("vctrs::vec_cast", "glue.character")
 
-  if (isNamespaceLoaded("knitr")) {
+  if (isNamespaceLoaded("knitr") &&
+      "knit_engines" %in% getNamespaceExports("knitr")) {
     knitr::knit_engines$set(glue = eng_glue, glue_sql = eng_glue_sql, gluesql = eng_glue_sql)
   } else {
     setHook(packageEvent("knitr", "onLoad"), function(...) {
